summaryrefslogtreecommitdiff
path: root/inc/pageutils.php
diff options
context:
space:
mode:
Diffstat (limited to 'inc/pageutils.php')
-rw-r--r--inc/pageutils.php7
1 files changed, 4 insertions, 3 deletions
diff --git a/inc/pageutils.php b/inc/pageutils.php
index b04f6e596..1e0792b7d 100644
--- a/inc/pageutils.php
+++ b/inc/pageutils.php
@@ -4,6 +4,7 @@
*
* @license GPL 2 (http://www.gnu.org/licenses/gpl.html)
* @author Andreas Gohr <andi@splitbrain.org>
+ * @todo Combine similar functions like {wiki,media,meta}FN()
*/
/**
@@ -131,17 +132,17 @@ function wikiFN($id,$rev=''){
}
/**
* returns the full path to the mailist specified by ID
*
* The filename is URL encoded to protect Unicode chars
*
* @author Steven Danz <steven-danz@kc.rr.com>
*/
-function wikiMN($id){
+function metaFN($id,$ext){
global $conf;
$id = cleanID($id);
$id = str_replace(':','/',$id);
- $fn = $conf['metadir'].'/'.utf8_encodeFN($id).'.mlist';
+ $fn = $conf['metadir'].'/'.utf8_encodeFN($id).$ext;
return $fn;
}
@@ -131,17 +132,17 @@ function wikiFN($id,$rev=''){
}
/**
- * returns the full path to the mailist specified by ID
+ * returns the full path to the meta file specified by ID and extension
*
* The filename is URL encoded to protect Unicode chars